@@ -14,6 +14,7 @@ predict.rfsrc <-
            distance = FALSE,
            var.used = c(FALSE, "all.trees", "by.tree"),
            split.depth = c(FALSE, "all.trees", "by.tree"),
+           case.depth = FALSE,
            seed = NULL,
            do.trace = FALSE,
            membership = FALSE,
@@ -36,6 +37,7 @@ predict.rfsrc <-
                                           distance = distance,                                          
                                           var.used = var.used,
                                           split.depth = split.depth,
+                                          case.depth = case.depth,
                                           seed = seed,
                                           do.trace = do.trace,
                                           membership = membership,
